ProSHADE: Class Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - d -

- deepCopyMap() : ProSHADE_internal_data::ProSHADE_data
- detectedSymmetry : ProSHADE_settings
- detectSymmetryFromAngleAxisSpace() : ProSHADE_internal_data::ProSHADE_data
- detectSymmetryInStructure() : ProSHADE_internal_data::ProSHADE_data
- detectSymmetryInStructurePython() : ProSHADE_internal_data::ProSHADE_data
- determineAllSHValues() : ProSHADE_settings
- determineBandwidth() : ProSHADE_settings
- determineBandwidthFromAngle() : ProSHADE_settings
- determineIntegrationOrder() : ProSHADE_settings
- determineSphereDistances() : ProSHADE_settings